@@ -9,7 +9,7 @@ from ..dialog import InteractiveDialog
 @InteractiveDialog.register_as_subclass('project-name')
 class ProjectNameDialog:
     def dialog(self, cookie_vars) -> Mapping[str, str]:
-        print(f"\n\n---- {cookie_vars['rtd_python_version']}")
+        # TODO: automatically create list from cookiecutter json
         return prompt(
             [
                 {
@@ -29,33 +29,48 @@ class ProjectNameDialog:
                     'type': 'input',
                     'name': 'project_slug',
                     'message': 'Enter the Project Slug (ie lowercase text, no spaces):',
-                    'default': lambda answers: answers['project_name']
-                    .lower()
-                    .replace(' ', '-'),
+                    'default': cookie_vars.get('project_slug')
+                    or (lambda answers: answers['project_name'].lower().replace(' ', '-')),
                 },
                 {
                     'type': 'input',
                     'name': 'pkg_name',
                     'message': 'Enter the Package Name (ie lowercase text, no spaces):',
-                    'default': lambda answers: answers['project_slug'].replace('-', '_'),
+                    'default': (
+                        cookie_vars['pkg_name']
+                        if cookie_vars.get('pkg_name')
+                        else (lambda answers: answers['project_slug'].replace('-', '_'))
+                    ),
                 },
                 {
                     'type': 'input',
                     'name': 'repo_name',
                     'message': 'Enter the Repository Name (ie lowercase text, no spaces):',
-                    'default': lambda answers: answers['project_slug'],
+                    'default': (
+                        cookie_vars['repo_name']
+                        if cookie_vars.get('repo_name')
+                        else (lambda answers: answers['project_slug'])
+                    ),
                 },
                 {
                     'type': 'input',
                     'name': 'readthedocs_project_slug',
                     'message': 'Enter the ReadTheDocs Project Slug (ie lowercase text, no spaces):',
-                    'default': lambda answers: answers['project_slug'],
+                    'default': (
+                        cookie_vars['readthedocs_project_slug']
+                        if cookie_vars.get('readthedocs_project_slug')
+                        else (lambda answers: answers['project_slug'])
+                    ),
                 },
                 {
                     'type': 'input',
                     'name': 'docker_image',
                     'message': 'Enter the Docker Image Name (ie lowercase text, no spaces):',
-                    'default': lambda answers: answers['project_slug'],
+                    'default': (
+                        cookie_vars['docker_image']
+                        if cookie_vars.get('docker_image')
+                        else (lambda answers: answers['project_slug'])
+                    ),
                 },
                 # full_name
                 {
@@ -69,7 +84,8 @@ class ProjectNameDialog:
                     'type': 'input',
                     'name': 'author',
                     'message': 'Enter author:',
-                    'default': lambda answers: answers['full_name'],
+                    'default': cookie_vars.get('author')
+                    or (lambda answers: answers['full_name']),
                 },
                 # author_email
                 {
@@ -97,7 +113,8 @@ class ProjectNameDialog:
                     'type': 'input',
                     'name': 'pypi_subtitle',
                     'message': 'Enter pypi_subtitle:',
-                    'default': lambda answers: answers['project_short_description'],
+                    'default': cookie_vars.get('pypi_subtitle')
+                    or (lambda answers: answers['project_short_description']),
                 },
                 # release_date
                 {
@@ -158,5 +175,21 @@ class ProjectNameDialog:
                     'choices': cookie_vars['rtd_python_version']['choices'],
                     'default': cookie_vars['rtd_python_version']['default'],
                 },
+                # CICD Pipeline design: stable, experimental (the good one)
+                {
+                    'type': 'select',
+                    'name': 'cicd',
+                    'message': 'Select the CI/CD Pipeline Design',
+                    'choices': cookie_vars['cicd']['choices'],
+                    'default': cookie_vars['cicd']['default'],
+                },
+                # Grafana / Loki compose stack inclusion
+                {
+                    'type': 'select',
+                    'name': 'include_observability',
+                    'message': 'Include Observability Compose Stack (Grafana, Loki)?',
+                    'choices': cookie_vars['include_observability']['choices'],
+                    'default': cookie_vars['include_observability']['default'],
+                },
             ]
         )
