@@ -75,6 +75,13 @@ def sdist_expected_correct_file_structure():
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/scripts/visualize-ga-workflow.py',
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/setup.cfg',
         'src/cookiecutter_python/{{ cookiecutter.project_slug }}/tox.ini',
+        # OBSERVABILITY COMPOSE STACK: GRAFANA, LOKI
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.include_observability == "yes" %}observability{% else %}PyGen_TO_DELETE_OBSERVABILITY{% endif %}/README.md',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.include_observability == "yes" %}observability{% else %}PyGen_TO_DELETE_OBSERVABILITY{% endif %}/docker-compose.observability.yml',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.include_observability == "yes" %}observability{% else %}PyGen_TO_DELETE_OBSERVABILITY{% endif %}/grafana/dashboards/dashboard.yml',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.include_observability == "yes" %}observability{% else %}PyGen_TO_DELETE_OBSERVABILITY{% endif %}/grafana/datasources/loki.yml',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.include_observability == "yes" %}observability{% else %}PyGen_TO_DELETE_OBSERVABILITY{% endif %}/loki/loki-config.yml',
+        'src/cookiecutter_python/{{ cookiecutter.project_slug }}/{% if cookiecutter.include_observability == "yes" %}observability{% else %}PyGen_TO_DELETE_OBSERVABILITY{% endif %}/promtail/promtail-config.yml',
         'src/cookiecutter_python/_find_lib.py',
         'src/cookiecutter_python/__init__.py',
         'src/cookiecutter_python/__main__.py',
@@ -146,6 +153,7 @@ def sdist_expected_correct_file_structure():
         # 'src/stubs/requests_futures/sessions.pyi',
     )
     TESTS = (
+        'tests/test_observability.py',
         'tests/test_version_string.py',
         'tests/test_git_sdk.py',
         'tests/test_git_porcelain.py',
@@ -289,12 +297,16 @@ def sdist_expected_correct_file_structure():
         'tests/test_ci_pipeline_generation.py',
         'tests/test_cli.py',
         'tests/test_cookiecutter_choice_var.py',
-        'tests/test_cookiecutter_context.py',
+        'tests/context/conftest.py',
+        'tests/context/test_cookiecutter_context.py',
+        'tests/context/test_generate_context_unit.py',
+        'tests/context/test_yes_no_in_cookiecutter_json.py',
         'tests/test_dialog_system.py',
         'tests/test_docs_gen_feat_compatibillity.py',
         'tests/test_error_classifier.py',
         'tests/test_generate.py',
         'tests/test_gold_standard.py',
+        'tests/test_interactive_config_bug.py',
         'tests/test_module.py',
         'tests/test_post_hook.py',
         'tests/test_prehook.py',
@@ -308,7 +320,7 @@ def sdist_expected_correct_file_structure():
         'pyproject.toml',
         'README.md',
         'LICENSE',
-        'CHANGELOG.rst',
+        'CHANGELOG.md',
         'CONTRIBUTING.md',
     )
     # Injected by Build Backend (Process)
