@@ -161,9 +161,9 @@ def test_cli_offline(
     )
 
     package_exists_on_readthedocs = check_readthedocs_result(result.stdout)
-    assert package_exists_on_readthedocs == check_web_server_expected_result(
-        'readthedocs'
-    )(config, FOUND_ON_READTHEDOCS)
+    assert package_exists_on_readthedocs == check_web_server_expected_result('readthedocs')(
+        config, FOUND_ON_READTHEDOCS
+    )
 
 
 @pytest.fixture
